summaryrefslogtreecommitdiffstats
path: root/gui/polkitqt1-gui-actionbuttons.h
diff options
context:
space:
mode:
Diffstat (limited to 'gui/polkitqt1-gui-actionbuttons.h')
-rw-r--r--gui/polkitqt1-gui-actionbuttons.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/gui/polkitqt1-gui-actionbuttons.h b/gui/polkitqt1-gui-actionbuttons.h
index b02ddb902..4e5988fd0 100644
--- a/gui/polkitqt1-gui-actionbuttons.h
+++ b/gui/polkitqt1-gui-actionbuttons.h
@@ -23,7 +23,7 @@
#include "polkitqt1-gui-actionbutton.h"
-namespace PolkitQt1
+namespace PolkitTQt1
{
namespace Gui
@@ -34,10 +34,10 @@ class ActionButtonsPrivate;
* \class ActionButtons polkitqt1-gui-actionbuttons.h ActionButtons
* \author Dario Freddi <drf@kde.org>
*
* \brief Class used to hold and update a list of QAbstractButtons
*
* This class is a convenience wrapper around ActionButton that lets
* you associate an undefined number of QAbstractButtons with a single
* action. Every button will be updated accordingly upon action's properties
* changes.
*
@@ -47,23 +47,23 @@ class ActionButtons : public ActionButton
{
Q_OBJECT
Q_DECLARE_PRIVATE(ActionButtons)
- Q_DISABLE_COPY(ActionButtons)
+ TQ_DISABLE_COPY(ActionButtons)
public:
/**
* Constructs a new ActionButton. You need to pass this
* constructor an existing list of QAbstractButtons, whose properties
* will be modified according to the underlying Action
* object. As ActionButtons inherits from Action, you can
* define your buttons' behavior right through this wrapper.
*
* \see Action
*
* \param buttons the QAbstractButton to associate to this ActionButton
* \param actionId the action Id to create the underlying Action
* \param parent the parent object
*/
- explicit ActionButtons(const QList<QAbstractButton *> &buttons, const QString &actionId = QString(), QObject *parent = 0);
+ explicit ActionButtons(const TQList<TQAbstractButton *> &buttons, const TQString &actionId = TQString(), TQObject *parent = 0);
virtual ~ActionButtons();
/**
@@ -71,7 +71,7 @@ public:
*
* \note If you are calling this function, you're probably
* changing the buttons list the action is referring to. If this
- * is the case, please note that Polkit-Qt does not handle
+ * is the case, please note that Polkit-TQt does not handle
* the previous buttons' memory, so you should take care of
* deleting them yourself (if needed). You can retrieve it by
* using buttons()
@@ -80,14 +80,14 @@ public:
*
* \param buttons the new buttons associated with the underlying action
*/
- void setButtons(const QList<QAbstractButton *> &buttons);
+ void setButtons(const TQList<TQAbstractButton *> &buttons);
/**
* Returns the current buttons list
*
* \return the buttons currently associated with the underlying action
*/
- QList<QAbstractButton *> buttons() const;
+ TQList<TQAbstractButton *> buttons() const;
/**
* Adds a button to the current button list. The button's properties
@@ -95,16 +95,16 @@ public:
*
* \param button the button to add
*/
- void addButton(QAbstractButton *button);
+ void addButton(TQAbstractButton *button);
/**
- * Removes a button from the current list. Please note that Polkit-Qt
+ * Removes a button from the current list. Please note that Polkit-TQt
* does not handle the removed button's memory, so you should take care of
* deleting it yourself (if needed).
*
* \param button the button to remove
*/
- void removeButton(QAbstractButton *button);
+ void removeButton(TQAbstractButton *button);
};
}
@@ -34,10 +34,10 @@ class ActionButtonsPrivate;
* \author Dario Freddi <drf@kde.org>
*
- * \brief Class used to hold and update a list of QAbstractButtons
+ * \brief Class used to hold and update a list of TQAbstractButtons
*
* This class is a convenience wrapper around ActionButton that lets
@@ -34,10 +34,10 @@ class ActionButtonsPrivate;
*
* This class is a convenience wrapper around ActionButton that lets
- * you associate an undefined number of QAbstractButtons with a single
+ * you associate an undefined number of TQAbstractButtons with a single
* action. Every button will be updated accordingly upon action's properties
* changes.
@@ -47,23 +47,23 @@ class ActionButtons : public ActionButton
/**
* Constructs a new ActionButton. You need to pass this
- * constructor an existing list of QAbstractButtons, whose properties
+ * constructor an existing list of TQAbstractButtons, whose properties
* will be modified according to the underlying Action
* object. As ActionButtons inherits from Action, you can
@@ -47,23 +47,23 @@ class ActionButtons : public ActionButton
* \see Action
*
- * \param buttons the QAbstractButton to associate to this ActionButton
+ * \param buttons the TQAbstractButton to associate to this ActionButton
* \param actionId the action Id to create the underlying Action
* \param parent the parent object